### Welcome to METATUTU library

METATUTU library (metatutu) is an open source python library with some useful
tools to help software development in all areas covered.

The library is developed by Wooloo Studio, an independent software development
team with experienced programmers, engineers and management team from varitey
of industries and background.  Most of them had experience in building world
class and award winning software products in their respective industry for
performance, user experience and reputation.

Thanks for supporting METATUTU and wish you enjoy using it!
Should you have any suggestion or question, please feel free to contact us.
